Nierenzellkarzinom

Studienergebnisse (randomisierte Phase II Studien, Phase III Studien, Metaanalysen)

Adjuvante Systemtherapie

Palliative Systemtherapie

Bevacizumab

Everolimus

Interferon Alpha

Interleukin-2

Pazopanib

Sorafenib

Sunitinib

Temsirolimus

andere (Lapatinib)

Chirurgische Therapiemaßnahmen

Nephrektomie bei IFN Alpha Therapie

Adjuvante medikamentöse Tumortherapie

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RFÜ2 (%) | ÜLZ3 (%) | Anmerkung | DOI4, PMID5
Pizzocaro, 2001 |  | T3a-b, N0 T2-3, N1-3 | Beobachtung | IFN 6 | 264 |  | 66,57 vs 66,0 n. s.8 |  | http://jco.ascopubs.org/content/19/2/425.long
Messing, 2003 |  | T3 - 4a, N-/+ | Beobachtung | IFN  | 283 | 2,2 vs 3,0 n. s. | 5,1 vs 7,4 n. s. |  | http://jco.ascopubs.org/content/21/7/1214.full
Jocham, 2004 |  | T2 - 3b, N-/+ | Beobachtung | autologe Vakzine | 558 | 67,8 vs 77,4 p = 0,0204 |  |  | http://www.thelancet.com/journals/lancet/article/PIIS0140-6736(04)15590-6
Atzpodien, 2005 |  | T3b/c-4, N0 | Beobachtung | IFN IL-2 / FU | 203 | 42 vs 498 n. s. | 58 vs 769 p = 0,0278 | 2:1 randomisiert | http://www.nature.com/bjc/journal/v92/n5/full/6602443a.html
Wood, 2008 |  | cT1b - 4, N-/+ | Beobachtung | HSPPC-66 | 818 | n. s. | n. s. |  | http://www.thelancet.com/journals/lancet/article/PIIS0140-6736(08)60697-2

1 N - Anzahl Patienten; 2 RFÜ - rezidivfreie Überlebenszeit in Monaten; 3 ÜLZ - Gesamtüberlebenszeit in Monaten; 4 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 5 PMID - System zur Identifizierung der Publikation in Pubmed; 6 Therapie: FU – 5Fluorouracil, HSPPC-66 – Heat Shock Protein, IFN - Interferon Alpha, IL-2 – Interleukin-2; Therapie: Nephrektomie - radikale Nephrektomie; 7 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 8 n. s. - nicht signifikant; 9 rezidivfreie Überlebensrate nach 5 Jahren in %; 10 Gesamtüberlebensrate nach 5 Jahren in %;

Palliative medikamentöse Tumortherapie

Bevacizumab

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Yang, 2003 |  | Zweitlinie, klarzellig | Placebo | Bev7 | 79 | 0 vs 108 n. s. 9 | 2,5 vs 4,8 p < 0,001 |  |  | http://www.nejm.org/doi/full/10.1056/NEJMoa021491
Escudier, 2007 | AVOREN | Erstlinie, klarzellig | IFN | Bev + IFN | 649 | 13 vs 31 p = 0,0001 | 5,4 vs 10,2 p = 0,0001 | 19,8 vs n. e.10 n. s. |  | http://www.thelancet.com/journals/lancet/article/PIIS0140-6736(07)61904-7/fulltext
Rini, 2008 / 2010 | CALGB 90206 | Erstlinie, klarzellig | IFN | Bev + IFN | 732 | 13,1 vs 25,5 p < 0,0001 | 5,2 vs 8,5 p < 0,0001 | 17,4 vs 18,3 n. s. |  | http://jco.ascopubs.org/content/26/33/5422.full http://jco.ascopubs.org/content/28/13/2137

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: Bev - Bevacizumab; IFN - Interferon Alpha; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 9 n. s. - nicht signifikant; 10 n. e. - Median nicht erreicht;

Palliative medikamentöse Tumortherapie

Everolimus

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Motzer, 2010 Motzer, 2009 | RECORD-1 | Zweitlinie, klarzellig, nach Sunitinib und / oder Sorafenib | Placebo | Eve7 | 416 | 08 vs 1,8 n. s. | 1,99 vs 4,9 p < 0,001 | 14,4 vs 14,8 n. s.9 | 2:1 randomisiert | http://onlinelibrary.wiley.com/doi/10.1002/cncr.25219/abstract /a> http://www.thelancet.com/journals/lancet/article/PIIS0140-6736(08)61039-9/fulltext

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: Eve - Everolimus; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 9 n. s. - nicht signifikant

Palliative medikamentöse Tumortherapie

Interferon Alpha

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 (HR4) | ÜLZ5 (HR) | Anmerkung | DOI6, PMID7
Negrier, 1998 |  | Erstlinie | IL-28 | IL-2 + IFN | 278 | 79 vs 19 p < 0,01 | n. s.10 | 12 vs 17 n. s. |  | http://www.nejm.org/doi/full/10.1056/NEJM199804303381805
MRC, 1999 |  | Erstlinie | MPA | IFN | 350 | 2 vs 14 | 0,72 p = 0,009 | 0,72 p = 0,017 |  | http://www.thelancet.com/journals/lancet/article/PIIS0140-6736(98)03544-2/fulltext
Negrier, 2007 |  | Erstlinie | MPA / IL-2 | IFN | 492 | 2,5 vs 7 n. s. | 3,2 vs 3,5 n. s. | 15,1 vs 15,4 n. s. |  | http://onlinelibrary.wiley.com/doi/10.1002/cncr.23056/full
Gore, 2010 |  | Erstlinie | IFN | IFN + IL-2 + FU | 1006 | 16 vs 23 p = 0,0045 | 5,5 vs 5,3 n. s. | 18,8 vs 18,6 n. s. |  | http://www.thelancet.com/journals/lancet/article/PIIS0140-6736(09)61921-8/fulltext
Coppin, 2010 |  | Erstlinie | keine Immuntherapie | IFN | 644 | 2 vs 12,5 p = 0,000017 |  | 7,6 vs 11,4 p = 0,00049 | Cochrane Analyse | http://onlinelibrary.wiley.com/o/cochrane/clsysrev/articles/CD006017/frame.html

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 HR - Hazard Ratio; 5 ÜLZ - Gesamtüberlebenszeit in Monaten; 6 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 7 PMID - System zur Identifizierung der Publikation in Pubmed; 8 Therapie: IFN - Interferon alpha, IL-2 - Interleukin - 2, MPA - Medroxprogesteronacetat; 9 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 10 n. s. - nicht signifikant

Palliative medikamentöse Tumortherapie

Interleukin – 2

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Yang, 1994 |  | Erstlinie | niedrig dosiert7 | hoch dosiert | 125 | 158 vs 20 n. s.9 |  | n. s. |  | http://jco.ascopubs.org/content/12/8/1572.abstract
Negrier, 1998 |  | Erstlinie | IFN | IFN + IL-2 | 287 | 8 vs 19 p < 0,01 | n. s. | 13 vs 17 n. s. |  | http://www.nejm.org/doi/full/10.1056/NEJM199804303381805
Atzpodien, 2001 |  | Erstlinie | Tam | IL-2 + IFN + FU | 78 | 0 vs 39,1 | 0 vs 7 p < 0,0001 | 13 vs 24 p = 0,0325 |  | http://www.nature.com/bjc/journal/v85/n8/pdf/6692076a.pdf
Negrier, 2007 |  | Erstlinie | MPA / IFN | IL-2 | 492 | 2,5 vs 7 n. s. | 3,2 vs 3,5 n. s. | 14,9 vs 15,7 n. s. |  | http://onlinelibrary.wiley.com/doi/10.1002/cncr.23056/full

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: FU - Fluorouracil, IFN - Interferon alpha, IL-2 - Interleukin - 2, MPA - Medroxprogesteronacetat; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 9 n. s. - nicht signifikant

Palliative medikamentöse Tumortherapie

Pazopanib

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Sternberg, 2010 |  | Erst- und Zweitlinie, klarzellig | Placebo | Paz7 | 435 | 38 vs 30 p < 0,001 | 4,2 vs 9,2 p < 0,0001 |  | 2:1 randomisiert | http://jco.ascopubs.org/content/27/22/3584.full

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: Paz - Pazopanib; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie;

Palliative medikamentöse Tumortherapie

Sorafenib

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Escudier, 2009 |  | Erstlinie, klarzellig | IFN7 | So | 189 | 8,78 vs 5,2 n. s.9 | 5,6 vs 5,7 n. s. | 14,9 vs 15,7 n. s. |  | http://jco.ascopubs.org/content/27/8/1280.full
Escudier, 2007 Escudier, 2009 | TARGET | Zweitlinie, niedriges und intermediäres Risiko | Placebo | So | 903 | 0 vs 2 n. s. | 2,8 vs 5,5 p < 0,000001 | 15,2 vs 17,8 n. s. |  | http://www.nejm.org/doi/full/10.1056/NEJMoa060655 http://jco.ascopubs.org/content/27/20/3312.full
Jonasch, 2010 |  | Erstlinie, klarzellig | So | So + IFN | 80 | 30 vs 25 n. s. | 7,4 vs 7,6 n. s. | n.e.10 vs 27,0 n. s. |  | http://onlinelibrary.wiley.com/doi/10.1002/cncr.24685/full

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: IFN - Interferon alpha, So - Sorafenib; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 9 n. s. - nicht signifikant;

Palliative medikamentöse Tumortherapie

Sunitinib

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Motzer, 2009 |  | Erstlinie, klarzellig | IFN7 | Su | 750 | 128 vs 47 p < 0,001 | 5 vs 11 p < 0,001 | 26,4 vs 32,9 p = 0,051 |  | http://jco.ascopubs.org/content/27/22/3584.full

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: IFN - Interferon alpha, So - Sunitinib; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie;

Palliative medikamentöse Tumortherapie

Temsirolimus

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Hudes, 2007 | ARCC | Erstlinie, hohes Risiko | IFN7 | Tem | 416 | 4,88 vs 8,6 n. s.9 | 3,1 vs 5,5 p < 0,001 | 7,3 vs 10,9 p = 0,008 |  | http://www.nejm.org/doi/full/10.1056/NEJMoa066838
Hudes, 2007 | ARCC | Erstlinie, hohes Risiko | Tem | Tem + IFN | 419 | 8,6 vs 8,1 n. s. | 5,5 vs 4,7 n. s. | 10,9 vs 8,4 n. s. |  | http://www.nejm.org/doi/full/10.1056/NEJMoa066838

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: IFN - Interferon alpha, Tem - Temsirolimus; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 9 n. s. - nicht signifikant;

Palliative medikamentöse Tumortherapie

andere (Lapatinib)

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RR2 | PFÜ3 | ÜLZ4 | Anmerkung | DOI5, PMID6
Ravaud, 2008 |  | Zweitlinie, nach Zytokinen | Tam / MPA | Lap | 416 | 0,58 vs 1,4 n. s. | 4 vs 4 n. s. | 10 vs 11 n. s. | signifikanter Vorteil bei TTP und ÜLZ bei Patienten mit EGFR 3+ | http://jco.ascopubs.org/content/26/14/2285.full

1 N - Anzahl Patienten; 2 RR - Remissionsrate; 3 PFÜ - progressionsfreie Überlebenszeit oder TTP – Zeit bis zum Progress, in Monaten; 4 ÜLZ - Gesamtüberlebenszeit in Monaten; 5 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 6 PMID - System zur Identifizierung der Publikation in Pubmed; 7 Therapie: Lap – Lapatinib, Mpa - Medroxyprogesteronacetat, Tam - Tamoxifen; 8 Ergebnis für Kontrolle, Ergebnis für neue Therapie; 9 n. s. - nicht signifikant;

Chirurgische Therapiemaßnahmen

Nephrektomie bei IFN Alpha Therapie

Erstautor / Jahr | Studie | Patienten | Kontrolle | Neue Therapie | N1 | RFÜ2 | ÜLZ3 | Anmerkung | DOI4, PMID5
Mickisch, 2001 | EORTC 30957 | fortgeschritten | Beobachtung | Nephrektomie6 | 241 |  | 77 vs 17 p = 0,03 |  | http://www.thelancet.com/journals/lancet/article/PIIS0140-6736(01)06103-7/fulltext
Lara, 2009 | S8949 | fortgeschritten | Beobachtung | Nephrektomie | 85 |  | 8,1 vs 11,1 p = 0,021 |  | http://www.jurology.com/article/S0022-5347(08)02707-9/abstract

1 N - Anzahl Patienten; 2 PFÜ - progressionsfreie Überlebenszeit; 3 ÜLZ - Gesamtüberlebenszeit in Monaten; 4 DOI - Digital Object Identifier: System zur Identifizierung der Publikation im Internet; 5 PMID - System zur Identifizierung der Publikation in Pubmed; 6 Therapie: Nephrektomie - radikale Nephrektomie; 7 Ergebnis für Kontrolle, Ergebnis für neue Therapie;